@@ -612,6 +612,36 @@ class EssClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DescribeOrganizationSeals(self, request):
+        """查询企业印章的列表，需要操作者具有查询印章权限
+        客户指定需要获取的印章数量和偏移量，数量最多100，超过100按100处理；入参InfoType控制印章是否携带授权人信息，为1则携带，为0则返回的授权人信息为空数组。接口调用成功返回印章的信息列表还有企业印章的总数。
+
+        :param request: Request instance for DescribeOrganizationSeals.
+        :type request: :class:`tencentcloud.ess.v20201111.models.DescribeOrganizationSealsRequest`
+        :rtype: :class:`tencentcloud.ess.v20201111.models.DescribeOrganizationSealsResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeOrganizationSeals", params, headers=headers)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DescribeOrganizationSealsResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DescribeThirdPartyAuthCode(self, request):
         """通过AuthCode查询用户是否实名
 
