@@ -511,3 +511,9 @@ UNSUPPORTEDOPERATION_UNPAIDORDER = 'UnsupportedOperation.UnpaidOrder'
 
 # 存在重复VPN。
 UNSUPPORTEDOPERATION_VPNDUPKEYEXIST = 'UnsupportedOperation.VPNDupKeyExist'
+
+# Video账户未创建，请检查后重新操作。
+UNSUPPORTEDOPERATION_VIDEOACCOUNTNOTEXIST = 'UnsupportedOperation.VideoAccountNotExist'
+
+# Video平台license数量不足。
+UNSUPPORTEDOPERATION_VIDEOINSUFFICIENTLICENSES = 'UnsupportedOperation.VideoInsufficientLicenses'
